@@ -68,6 +68,7 @@ from sqlalchemy.ext.declarative import declared_attr
 from obspy.core import UTCDateTime
 #from pisces.schema.util import ORMParent 
 from pisces.schema.util import PiscesMeta
+from pisces.schema.util import parse_str, parse_int, parse_float
 from pisces.io.trace import wfdisc2trace
 
 #TODO: check __table_args__ syntax for final empty {}
@@ -93,300 +94,305 @@ Base = declarative_base(metaclass=PiscesMeta, constructor=None)
 # TODO: write a parser that gets the width (and type?) from info['format']
 
 # specialized string parsing functions 
-def strip(s):
-    return str(s).strip()
 
 # TODO: use dateutil module to handle wildcard characters, etc.?
+# https://docs.python.org/2.7/library/datetime.html#strftime-strptime-behavior
+# https://docs.python.org/2/library/string.html#format-specification-mini-language
 DATEFMT = '%Y-%m-%d %H:%M:%S'
 def dtfn(s):
-    return datetime.strptime(s, DATEFMT)
+    try:
+        val = datetime.strptime(s, DATEFMT)
+    except ValueError:
+        val = None
+    return val
 
-algorithm = Column(String(15), info={'default': '-', 'parse': strip, 'dtype': 'a15', 'width': 15, 'format': '15.15s'})
+algorithm = Column(String(15), 
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a15', 'width': 15, 'format': '15.15s'})
 amp = Column(Float(24), 
-        info={'default': -1.0, 'parse': float, 'dtype': 'float', 'width': 11, 'format': '11.2f'})
+        info={'default': -1.0, 'parse': parse_float, 'dtype': 'float', 'width': 11, 'format': '11.2f'})
 ampid = Column(Integer, nullable=False, 
-        info={'default': -1, 'parse': int, 'dtype': 'int', 'width': 9, 'format': '9d'})
-amptime = Column(Float(53), info={'default': -9999999999.999, 'parse': float,
+        info={'default': -1, 'parse': parse_int, 'dtype': 'int', 'width': 9, 'format': '9d'})
+amptime = Column(Float(53), info={'default': -9999999999.999, 'parse': parse_float,
         'dtype': 'float', 'width': 17, 'format': '17.5f'})
 amptype = Column(String(8), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a8', 'width': 8, 'format': '8.8s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a8', 'width': 8, 'format': '8.8s'})
 arid = Column(Integer, 
-        info={'default': -1, 'parse': int, 'dtype': 'int', 'width': 9, 'format': '9d'})
+        info={'default': -1, 'parse': parse_int, 'dtype': 'int', 'width': 9, 'format': '9d'})
 auth = Column(String(20), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a20', 'width': 20, 'format': '20.20s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a20', 'width': 20, 'format': '20.20s'})
 azdef = Column(String(1), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a1', 'width': 1, 'format': '1.1s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a1', 'width': 1, 'format': '1.1s'})
 azimuth = Column(Float(24), 
-        info={'default': -1.0, 'parse': float, 'dtype': 'float', 'width': 7, 'format': '7.2f'})
+        info={'default': -1.0, 'parse': parse_float, 'dtype': 'float', 'width': 7, 'format': '7.2f'})
 azres = Column(Float(24), 
-        info={'default': -999.0, 'parse': float, 'dtype': 'float', 'width': 7, 'format': '7.1f'})
+        info={'default': -999.0, 'parse': parse_float, 'dtype': 'float', 'width': 7, 'format': '7.1f'})
 band = Column(String(1), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a1', 'width': 1, 'format': '1.1s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a1', 'width': 1, 'format': '1.1s'})
 belief = Column(Float(24), 
-        info={'default': -1.0, 'parse': float, 'dtype': 'float', 'width': 4, 'format': '4.2f'})
+        info={'default': -1.0, 'parse': parse_float, 'dtype': 'float', 'width': 4, 'format': '4.2f'})
 calib = Column(Float(24), 
-        info={'default': -1.0, 'parse': float, 'dtype': 'float', 'width': 16, 'format': '16.6f'})
+        info={'default': -1.0, 'parse': parse_float, 'dtype': 'float', 'width': 16, 'format': '16.6f'})
 calper = Column(Float(24), 
-        info={'default': -1.0, 'parse': float, 'dtype': 'float', 'width': 16, 'format': '16.6f'})
+        info={'default': -1.0, 'parse': parse_float, 'dtype': 'float', 'width': 16, 'format': '16.6f'})
 calratio = Column(Float(24), 
-        info={'default': -1.0, 'parse': float, 'dtype': 'float', 'width': 16, 'format': '16.6f'})
+        info={'default': -1.0, 'parse': parse_float, 'dtype': 'float', 'width': 16, 'format': '16.6f'})
 chan = Column(String(8), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a8', 'width': 8, 'format': '8.8s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a8', 'width': 8, 'format': '8.8s'})
 chanid = Column(Integer, 
-        info={'default': -1, 'parse': int, 'dtype': 'int', 'width': 8, 'format': '8d'})
+        info={'default': -1, 'parse': parse_int, 'dtype': 'int', 'width': 8, 'format': '8d'})
 clip = Column(String(1), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a1', 'width': 1, 'format': '1.1s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a1', 'width': 1, 'format': '1.1s'})
 commid = Column(Integer, 
-        info={'default': -1, 'parse': int, 'dtype': 'int', 'width': 9, 'format': '9d'})
+        info={'default': -1, 'parse': parse_int, 'dtype': 'int', 'width': 9, 'format': '9d'})
 conf = Column(Float(24), 
-        info={'default': -1, 'parse': float, 'dtype': 'float', 'width': 5, 'format': '5.3f'})
+        info={'default': -1, 'parse': parse_float, 'dtype': 'float', 'width': 5, 'format': '5.3f'})
 ctype = Column(String(4), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a1', 'width': 1, 'format': '1.1s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a1', 'width': 1, 'format': '1.1s'})
 datatype = Column(String(2),
-        info={'default': '-', 'parse': strip, 'dtype': 'a2', 'width': 2, 'format': '2.2s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a2', 'width': 2, 'format': '2.2s'})
 deast = Column(Float(24), 
-        info={'default': 0.0, 'parse': float, 'dtype': 'float', 'width': 9, 'format': '9.4f'})
+        info={'default': 0.0, 'parse': parse_float, 'dtype': 'float', 'width': 9, 'format': '9.4f'})
 delaz = Column(Float(24), 
-        info={'default': -1.0, 'parse': float, 'dtype': 'float', 'width': 7, 'format': '7.2f'})
+        info={'default': -1.0, 'parse': parse_float, 'dtype': 'float', 'width': 7, 'format': '7.2f'})
 delslo = Column(Float(24), 
-        info={'default': -1.0, 'parse': float, 'dtype': 'float', 'width': 7, 'format': '7.2f'})
+        info={'default': -1.0, 'parse': parse_float, 'dtype': 'float', 'width': 7, 'format': '7.2f'})
 delta = Column(Float(24), 
-        info={'default': -1.0, 'parse': float, 'dtype': 'float', 'width': 8, 'format': '8.3f'})
+        info={'default': -1.0, 'parse': parse_float, 'dtype': 'float', 'width': 8, 'format': '8.3f'})
 deltaf = Column(Float(24), 
-        info={'default': -1.0, 'parse': float, 'dtype': 'float', 'width': 7, 'format': '7.3f'})
+        info={'default': -1.0, 'parse': parse_float, 'dtype': 'float', 'width': 7, 'format': '7.3f'})
 deltim = Column(Float(24), 
-        info={'default': -1.0, 'parse': float, 'dtype': 'float', 'width': 6, 'format': '6.3f'})
+        info={'default': -1.0, 'parse': parse_float, 'dtype': 'float', 'width': 6, 'format': '6.3f'})
 depdp = Column(Float(24), 
-        info={'default': -999, 'parse': float, 'dtype': 'float', 'width': 9, 'format': '9.4f'})
+        info={'default': -999, 'parse': parse_float, 'dtype': 'float', 'width': 9, 'format': '9.4f'})
 depth = Column(Float(24), 
-        info={'default': -999.0, 'parse': float, 'dtype': 'float', 'width': 9, 'format': '9.4f'})
+        info={'default': -999.0, 'parse': parse_float, 'dtype': 'float', 'width': 9, 'format': '9.4f'})
 descrip = Column(String(50), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a50', 'width': 50, 'format': '50.50s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a50', 'width': 50, 'format': '50.50s'})
 dfile = Column(String(32), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a32', 'width': 32, 'format': '32.32s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a32', 'width': 32, 'format': '32.32s'})
 digital = Column(String(1), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a1', 'width': 1, 'format': '1.1s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a1', 'width': 1, 'format': '1.1s'})
 dir = Column(String(64), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a64', 'width': 64, 'format': '64.64s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a64', 'width': 64, 'format': '64.64s'})
 dnorth = Column(Float(24), 
-        info={'default': 0.0, 'parse': float, 'dtype': 'float', 'width': 9, 'format': '9.4f'})
+        info={'default': 0.0, 'parse': parse_float, 'dtype': 'float', 'width': 9, 'format': '9.4f'})
 dtype = Column(String(1), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a1', 'width': 1, 'format': '1.1s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a1', 'width': 1, 'format': '1.1s'})
 duration = Column(Float(24), 
-        info={'default': -1.0, 'parse': float, 'dtype': 'float', 'width': 7, 'format': '7.2f'})
+        info={'default': -1.0, 'parse': parse_float, 'dtype': 'float', 'width': 7, 'format': '7.2f'})
 edepth = Column(Float(24), 
-        info={'default': -1.0, 'parse': float, 'dtype': 'float', 'width': 9, 'format': '9.4f'})
+        info={'default': -1.0, 'parse': parse_float, 'dtype': 'float', 'width': 9, 'format': '9.4f'})
 elev = Column(Float(24), 
-        info={'default': -999.0, 'parse': float, 'dtype': 'float', 'width': 9, 'format': '9.4f'})
+        info={'default': -999.0, 'parse': parse_float, 'dtype': 'float', 'width': 9, 'format': '9.4f'})
 ema = Column(Float(24), 
-        info={'default': -1.0, 'parse': float, 'dtype': 'float', 'width': 7, 'format': '7.2f'})
+        info={'default': -1.0, 'parse': parse_float, 'dtype': 'float', 'width': 7, 'format': '7.2f'})
 emares = Column(Float(24), 
-        info={'default': -999.0, 'parse': float, 'dtype': 'float', 'width': 7, 'format': '7.1f'})
+        info={'default': -999.0, 'parse': parse_float, 'dtype': 'float', 'width': 7, 'format': '7.1f'})
 endtime = Column(Float(53), info={'default':  9999999999.999, 
-    'parse': float, 'dtype': 'float', 'width': 17, 'format': '17.5f'})
+    'parse': parse_float, 'dtype': 'float', 'width': 17, 'format': '17.5f'})
 esaz = Column(Float(24), 
-        info={'default': -1, 'parse': float, 'dtype': 'float', 'width': 7, 'format': '7.2f'})
+        info={'default': -1, 'parse': parse_float, 'dtype': 'float', 'width': 7, 'format': '7.2f'})
 etype = Column(String(7), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a7', 'width': 7, 'format': '7.7s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a7', 'width': 7, 'format': '7.7s'})
 evid = Column(Integer, 
-        info={'default': -1, 'parse': int, 'dtype': 'int', 'width': 9, 'format': '9d'})
+        info={'default': -1, 'parse': parse_int, 'dtype': 'int', 'width': 9, 'format': '9d'})
 evname = Column(String(32), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a32', 'width': 32, 'format': '32.32s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a32', 'width': 32, 'format': '32.32s'})
 fm = Column(String(2), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a2', 'width': 2, 'format': '2.2s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a2', 'width': 2, 'format': '2.2s'})
 foff = Column(Integer, 
-        info={'default': -1, 'parse': int, 'dtype': 'int', 'width': 10, 'format': '10d'})
+        info={'default': -1, 'parse': parse_int, 'dtype': 'int', 'width': 10, 'format': '10d'})
 grn = Column(Integer, 
-        info={'default': -1, 'parse': int, 'dtype': 'int', 'width': 8, 'format': '8d'})
+        info={'default': -1, 'parse': parse_int, 'dtype': 'int', 'width': 8, 'format': '8d'})
 grname = Column(String(40), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a40', 'width': 40, 'format': '40.40s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a40', 'width': 40, 'format': '40.40s'})
 hang = Column(Float(24), 
-        info={'default': -1.0, 'parse': float, 'dtype': 'float', 'width': 6, 'format': '6.1f'})
+        info={'default': -1.0, 'parse': parse_float, 'dtype': 'float', 'width': 6, 'format': '6.1f'})
 inarrival = Column(String(1), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a1', 'width': 1, 'format': '1.1s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a1', 'width': 1, 'format': '1.1s'})
 inid = Column(Integer, 
-        info={'default': -1, 'dtype': 'int', 'width': 8, 'format': '8d'})
+        info={'default': -1, 'parse': parse_int, 'dtype': 'int', 'width': 8, 'format': '8d'})
 insname = Column(String(50), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a50', 'width': 50, 'format': '50.50s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a50', 'width': 50, 'format': '50.50s'})
 instant = Column(String(1), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a1', 'width': 1, 'format': '1.1s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a1', 'width': 1, 'format': '1.1s'})
 instype = Column(String(6), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a6', 'width': 6, 'format': '6.6s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a6', 'width': 6, 'format': '6.6s'})
 iphase = Column(String(8), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a8', 'width': 8, 'format': '8.8s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a8', 'width': 8, 'format': '8.8s'})
 jdate = Column(Integer, 
-        info={'default': -1, 'parse': int, 'dtype': 'int', 'width': 8, 'format': '8d'})
+        info={'default': -1, 'parse': parse_int, 'dtype': 'int', 'width': 8, 'format': '8d'})
 keyname = Column(String(15), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a15', 'width': 15, 'format': '15.15s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a15', 'width': 15, 'format': '15.15s'})
 keyvalue = Column(Integer, 
-        info={'default': -1, 'parse': int, 'dtype': 'int', 'width': 9, 'format': '9d'})
+        info={'default': -1, 'parse': parse_int, 'dtype': 'int', 'width': 9, 'format': '9d'})
 lat = Column(Float(53), 
-        info={'default': -999.0, 'parse': float, 'dtype': 'float', 'width': 11, 'format': '11.6f'})
+        info={'default': -999.0, 'parse': parse_float, 'dtype': 'float', 'width': 11, 'format': '11.6f'})
 #lddate = Column(DateTime, nullable=False, onupdate=datetime.now,
 #        info={'default': datetime.now, 'dtype': '|O8', 'width': 17, 'format': '%y-%m-%d %H:%M:%S'}) 
 lddate = Column(DateTime, nullable=False, onupdate=datetime.now,
         info={'default': datetime.now, 'parse': dtfn, 'dtype': 'O', 'width': 19, 'format': DATEFMT}) 
 #        info={'default': datetime.now, 'dtype': 'M', 'width': 17, 'format': '%y-%m-%d %H:%M:%S'}) 
 lineno = Column(Integer, 
-        info={'default': -1, 'parse': int, 'dtype': 'int', 'width': 8, 'format': '8d'})
+        info={'default': -1, 'parse': parse_int, 'dtype': 'int', 'width': 8, 'format': '8d'})
 logat = Column(Float(24), 
-        info={'default': -999.0, 'parse': float, 'dtype': 'float', 'width': 7, 'format': '7.2f'})
+        info={'default': -999.0, 'parse': parse_float, 'dtype': 'float', 'width': 7, 'format': '7.2f'})
 lon = Column(Float(53), 
-        info={'default': -999.0, 'parse': float, 'dtype': 'float', 'width': 11, 'format': '11.6f'})
+        info={'default': -999.0, 'parse': parse_float, 'dtype': 'float', 'width': 11, 'format': '11.6f'})
 #lon = Column(Float(53), 
 #        info={'default': -999.0, 'dtype': 'float', 'width': 11, 'format': '11.6f'})
 magid = Column(Integer, nullable=False, 
-        info={'default': -1, 'dtype': 'int', 'width': 9, 'format': '9d'})
+        info={'default': -1, 'parse': parse_int, 'dtype': 'int', 'width': 9, 'format': '9d'})
 magnitude = Column(Float(24), 
-        info={'default': -999.0, 'parse': float, 'dtype': 'float', 'width': 7, 'format': '7.2f'})
+        info={'default': -999.0, 'parse': parse_float, 'dtype': 'float', 'width': 7, 'format': '7.2f'})
 magres = Column(Float(24),
-        info={'default': -999, 'parse': float, 'dtype': 'float', 'width': 7, 'format': '7.2f'})
+        info={'default': -999, 'parse': parse_float, 'dtype': 'float', 'width': 7, 'format': '7.2f'})
 magdef = Column(String(1), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a1', 'width': 1, 'format': '1.1s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a1', 'width': 1, 'format': '1.1s'})
 magtype = Column(String(6), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a6', 'width': 6, 'format': '6.6s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a6', 'width': 6, 'format': '6.6s'})
 mb = Column(Float(24), 
-        info={'default': -999.0, 'parse': float, 'dtype': 'float', 'width': 7, 'format': '7.2f'})
+        info={'default': -999.0, 'parse': parse_float, 'dtype': 'float', 'width': 7, 'format': '7.2f'})
 mbid = Column(Integer, 
-        info={'default': -1, 'parse': int, 'dtype': 'int', 'width': 9, 'format': '9d'})
+        info={'default': -1, 'parse': parse_int, 'dtype': 'int', 'width': 9, 'format': '9d'})
 ml = Column(Float(24), 
-        info={'default': -999.0, 'parse': float, 'dtype': 'float', 'width': 7, 'format': '7.2f'})
+        info={'default': -999.0, 'parse': parse_float, 'dtype': 'float', 'width': 7, 'format': '7.2f'})
 mlid = Column(Integer, 
-        info={'default': -1, 'parse': int, 'dtype': 'int', 'width': 9, 'format': '9d'})
+        info={'default': -1, 'parse': parse_int, 'dtype': 'int', 'width': 9, 'format': '9d'})
 ms = Column(Float(24), 
-        info={'default': -999.0, 'parse': float, 'dtype': 'float', 'width': 7, 'format': '7.2f'})
+        info={'default': -999.0, 'parse': parse_float, 'dtype': 'float', 'width': 7, 'format': '7.2f'})
 msid = Column(Integer, 
-        info={'default': -1, 'parse': int, 'dtype': 'int', 'width': 9, 'format': '9d'})
+        info={'default': -1, 'parse': parse_int, 'dtype': 'int', 'width': 9, 'format': '9d'})
 mmodel = Column(String(15), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a15', 'width': 15, 'format': '15.15s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a15', 'width': 15, 'format': '15.15s'})
 nass = Column(Integer, 
-        info={'default': -1, 'parse': int, 'dtype': 'int', 'width': 4, 'format': '4d'})
+        info={'default': -1, 'parse': parse_int, 'dtype': 'int', 'width': 4, 'format': '4d'})
 ncalib = Column(Float(24), 
-        info={'default': 1.0, 'parse': float, 'dtype': 'float', 'width': 16, 'format': '16.6f'})
+        info={'default': 1.0, 'parse': parse_float, 'dtype': 'float', 'width': 16, 'format': '16.6f'})
 ncalper = Column(Float(24), 
-        info={'default': -1.0, 'parse': float, 'dtype': 'float', 'width': 16, 'format': '16.6f'})
+        info={'default': -1.0, 'parse': parse_float, 'dtype': 'float', 'width': 16, 'format': '16.6f'})
 ndef = Column(Integer, 
-        info={'default': -1, 'parse': int, 'dtype': 'int', 'width': 4, 'format': '4d'})
+        info={'default': -1, 'parse': parse_int, 'dtype': 'int', 'width': 4, 'format': '4d'})
 ndp = Column(Integer, 
-        info={'default': -1, 'parse': int, 'dtype': 'int', 'width': 4, 'format': '4d'})
+        info={'default': -1, 'parse': parse_int, 'dtype': 'int', 'width': 4, 'format': '4d'})
 net = Column(String(8), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a8', 'width': 8, 'format': '8.8s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a8', 'width': 8, 'format': '8.8s'})
 netname = Column(String(80), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a80', 'width': 80, 'format': '80.80s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a80', 'width': 80, 'format': '80.80s'})
 nettype = Column(String(4), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a4', 'width': 4, 'format': '4.4s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a4', 'width': 4, 'format': '4.4s'})
 nsamp = Column(Integer, 
-        info={'default': -1, 'parse': int, 'dtype': 'int', 'width': 8, 'format': '8d'})
+        info={'default': -1, 'parse': parse_int, 'dtype': 'int', 'width': 8, 'format': '8d'})
 nsta = Column(Integer, 
-        info={'default': -1, 'parse': int, 'dtype': 'int', 'width': 8, 'format': '8d'})
+        info={'default': -1, 'parse': parse_int, 'dtype': 'int', 'width': 8, 'format': '8d'})
 offdate = Column(Integer, 
-        info={'default': 2286324, 'parse': int, 'dtype': 'int', 'width': 8, 'format': '8d'})
+        info={'default': 2286324, 'parse': parse_int, 'dtype': 'int', 'width': 8, 'format': '8d'})
 ondate = Column(Integer, 
-        info={'default': -1, 'parse': int, 'dtype': 'int', 'width': 8, 'format': '8d'})
+        info={'default': -1, 'parse': parse_int, 'dtype': 'int', 'width': 8, 'format': '8d'})
 orid = Column(Integer, 
-        info={'default': -1, 'parse': int, 'dtype': 'int', 'width': 9, 'format': '9d'})
+        info={'default': -1, 'parse': parse_int, 'dtype': 'int', 'width': 9, 'format': '9d'})
 parid = Column(Integer, 
-        info={'default': -1, 'parse': int, 'dtype': 'int', 'width': 9, 'format': '9d'})
+        info={'default': -1, 'parse': parse_int, 'dtype': 'int', 'width': 9, 'format': '9d'})
 per = Column(Float(24), 
-        info={'default': -1.0, 'parse': float, 'dtype': 'float', 'width': 7, 'format': '7.2f'})
+        info={'default': -1.0, 'parse': parse_float, 'dtype': 'float', 'width': 7, 'format': '7.2f'})
 phase = Column(String(8), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a8', 'width': 8, 'format': '8.8s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a8', 'width': 8, 'format': '8.8s'})
 prefor = Column(Integer, 
-        info={'default': -1, 'parse': int, 'dtype': 'int', 'width': 8, 'format': '9d'})
+        info={'default': -1, 'parse': parse_int, 'dtype': 'int', 'width': 8, 'format': '9d'})
 qual = Column(String(1), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a1', 'width': 1, 'format': '1.1s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a1', 'width': 1, 'format': '1.1s'})
 rect = Column(Float(24), 
-        info={'default': -1.0, 'parse': float, 'dtype': 'float', 'width': 7, 'format': '7.3f'})
+        info={'default': -1.0, 'parse': parse_float, 'dtype': 'float', 'width': 7, 'format': '7.3f'})
 refsta = Column(String(6), 
-        info={'default': '-', 'parse': strip, 'dtype': 'str', 'width': 6, 'format': '6.6s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'str', 'width': 6, 'format': '6.6s'})
 remark = Column(String(80), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a80', 'width': 80, 'format': '80.80s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a80', 'width': 80, 'format': '80.80s'})
 rsptype = Column(String(6), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a6', 'width': 6, 'format': '6.6s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a6', 'width': 6, 'format': '6.6s'})
 samprate = Column(Float(24), 
-        info={'default': -1.0, 'parse': float, 'dtype': 'float', 'width': 11, 'format': '11.7f'})
+        info={'default': -1.0, 'parse': parse_float, 'dtype': 'float', 'width': 11, 'format': '11.7f'})
 sdepth = Column(Float(24), 
-        info={'default': -1, 'parse': float, 'dtype': 'float', 'width': 9, 'format': '9.4f'})
+        info={'default': -1, 'parse': parse_float, 'dtype': 'float', 'width': 9, 'format': '9.4f'})
 sdobs = Column(Float(24),
-        info={'default': -1, 'parse': float, 'dtype': 'float', 'width': 9, 'format': '9.4f'})
+        info={'default': -1, 'parse': parse_float, 'dtype': 'float', 'width': 9, 'format': '9.4f'})
 seaz = Column(Float(24), 
-        info={'default': -999.0, 'parse': float, 'dtype': 'float', 'width': 7, 'format': '7.2f'})
+        info={'default': -999.0, 'parse': parse_float, 'dtype': 'float', 'width': 7, 'format': '7.2f'})
 segtype = Column(String(1), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a1', 'width': 1, 'format': '1.1s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a1', 'width': 1, 'format': '1.1s'})
 slodef = Column(String(1), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a1', 'width': 1, 'format': '1.1s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a1', 'width': 1, 'format': '1.1s'})
 slores = Column(Float(24), 
-        info={'default': -999.0, 'parse': float, 'dtype': 'float', 'width': 7, 'format': '7.2f'})
+        info={'default': -999.0, 'parse': parse_float, 'dtype': 'float', 'width': 7, 'format': '7.2f'})
 slow = Column(Float(24), 
-        info={'default': -1.0, 'parse': float, 'dtype': 'float','width': 7, 'format': '7.2f'})
+        info={'default': -1.0, 'parse': parse_float, 'dtype': 'float','width': 7, 'format': '7.2f'})
 smajax = Column(Float(24), 
-        info={'default': -1, 'parse': float, 'dtype': 'float', 'width': 9, 'format': '9.4f'})
+        info={'default': -1, 'parse': parse_float, 'dtype': 'float', 'width': 9, 'format': '9.4f'})
 sminax = Column(Float(24), 
-        info={'default': -1, 'parse': float, 'dtype': 'float', 'width': 9, 'format': '9.4f'})
+        info={'default': -1, 'parse': parse_float, 'dtype': 'float', 'width': 9, 'format': '9.4f'})
 snr = Column(Float(24), 
-        info={'default': -1.0, 'parse': float, 'dtype': 'float', 'width': 10, 'format': '10.2f'})
+        info={'default': -1.0, 'parse': parse_float, 'dtype': 'float', 'width': 10, 'format': '10.2f'})
 srn = Column(Integer, 
-        info={'default': -1, 'parse': int, 'dtype': 'int', 'width': 8, 'format': '8d'})
+        info={'default': -1, 'parse': parse_int, 'dtype': 'int', 'width': 8, 'format': '8d'})
 srname = Column(String(80), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a80', 'width': 80, 'format': '80.80s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a80', 'width': 80, 'format': '80.80s'})
 sta = Column(String(6), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a6', 'width': 6, 'format': '6.6s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a6', 'width': 6, 'format': '6.6s'})
 staname = Column(String(50), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a50', 'width': 50, 'format': '50.50s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a50', 'width': 50, 'format': '50.50s'})
 stassid = Column(Integer, 
-        info={'default': -1, 'parse': int, 'dtype': 'int', 'width': 9, 'format': '9d'})
+        info={'default': -1, 'parse': parse_int, 'dtype': 'int', 'width': 9, 'format': '9d'})
 statype = Column(String(4), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a4', 'width': 4, 'format': '4.4s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a4', 'width': 4, 'format': '4.4s'})
 stime = Column(Float(24),
-        info={'default': -1, 'parse': float, 'dtype': 'float', 'width': 6, 'format': '6.2f'})
+        info={'default': -1, 'parse': parse_float, 'dtype': 'float', 'width': 6, 'format': '6.2f'})
 strike = Column(Float(24), 
-        info={'default': -1, 'parse': float, 'dtype': 'float', 'width': 6, 'format': '6.2f'})
+        info={'default': -1, 'parse': parse_float, 'dtype': 'float', 'width': 6, 'format': '6.2f'})
 stt = Column(Float(24),
-        info={'default': -100000000, 'parse': float, 'dtype': 'float', 'width': 15, 'format': '15.4f'})
+        info={'default': -100000000, 'parse': parse_float, 'dtype': 'float', 'width': 15, 'format': '15.4f'})
 stx = Column(Float(24),
-        info={'default': -100000000, 'parse': float, 'dtype': 'float', 'width': 15, 'format': '15.4f'})
+        info={'default': -100000000, 'parse': parse_float, 'dtype': 'float', 'width': 15, 'format': '15.4f'})
 sty = Column(Float(24),
-        info={'default': -100000000, 'parse': float, 'dtype': 'float', 'width': 15, 'format': '15.4f'})
+        info={'default': -100000000, 'parse': parse_float, 'dtype': 'float', 'width': 15, 'format': '15.4f'})
 stype = Column(String(1), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a1', 'width': 1, 'format': '1.1s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a1', 'width': 1, 'format': '1.1s'})
 stz = Column(Float(24),
-        info={'default': -100000000, 'parse': float, 'dtype': 'float', 'width': 15, 'format': '15.4f'})
+        info={'default': -100000000, 'parse': parse_float, 'dtype': 'float', 'width': 15, 'format': '15.4f'})
 sxx = Column(Float(24),
-        info={'default': -100000000, 'parse': float, 'dtype': 'float', 'width': 15, 'format': '15.4f'})
+        info={'default': -100000000, 'parse': parse_float, 'dtype': 'float', 'width': 15, 'format': '15.4f'})
 sxy = Column(Float(24),
-        info={'default': -100000000, 'parse': float, 'dtype': 'float', 'width': 15, 'format': '15.4f'})
+        info={'default': -100000000, 'parse': parse_float, 'dtype': 'float', 'width': 15, 'format': '15.4f'})
 sxz = Column(Float(24),
-        info={'default': -100000000, 'parse': float, 'dtype': 'float', 'width': 15, 'format': '15.4f'})
+        info={'default': -100000000, 'parse': parse_float, 'dtype': 'float', 'width': 15, 'format': '15.4f'})
 syy = Column(Float(24),
-        info={'default': -100000000, 'parse': float, 'dtype': 'float', 'width': 15, 'format': '15.4f'})
+        info={'default': -100000000, 'parse': parse_float, 'dtype': 'float', 'width': 15, 'format': '15.4f'})
 syz = Column(Float(24),
-        info={'default': -100000000, 'parse': float, 'dtype': 'float', 'width': 15, 'format': '15.4f'})
+        info={'default': -100000000, 'parse': parse_float, 'dtype': 'float', 'width': 15, 'format': '15.4f'})
 szz = Column(Float(24),
-        info={'default': -100000000, 'parse': float, 'dtype': 'float', 'width': 15, 'format': '15.4f'})
+        info={'default': -100000000, 'parse': parse_float, 'dtype': 'float', 'width': 15, 'format': '15.4f'})
 tagid = Column(Integer, 
-        info={'default': -1, 'parse': float, 'dtype': 'float', 'width': 9, 'format': '9d'})
+        info={'default': -1, 'parse': parse_float, 'dtype': 'float', 'width': 9, 'format': '9d'})
 tagname = Column(String(8), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a8', 'width': 8, 'format': '8.8s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a8', 'width': 8, 'format': '8.8s'})
 time = Column(Float(53), 
-        info={'default': -9999999999.999, 'parse': float, 'dtype': 'float', 'width': 17, 'format': '17.5f'})
+        info={'default': -9999999999.999, 'parse': parse_float, 'dtype': 'float', 'width': 17, 'format': '17.5f'})
 timedef = Column(String(1), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a1', 'width': 1, 'format': '1.1s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a1', 'width': 1, 'format': '1.1s'})
 timeres = Column(Float(24), 
-        info={'default': -999.0, 'parse': float, 'dtype': 'float', 'width': 8, 'format': '8.3f'})
+        info={'default': -999.0, 'parse': parse_float, 'dtype': 'float', 'width': 8, 'format': '8.3f'})
 tshift = Column(Float(24), 
-        info={'default': -100000000, 'parse': float, 'dtype': 'float', 'width': 16, 'format': '16.2f'})
+        info={'default': -100000000, 'parse': parse_float, 'dtype': 'float', 'width': 16, 'format': '16.2f'})
 uncertainty = Column(Float(24), 
-        info={'default': -1.0, 'parse': float, 'dtype': 'float', 'width': 7, 'format': '7.2f'})
+        info={'default': -1.0, 'parse': parse_float, 'dtype': 'float', 'width': 7, 'format': '7.2f'})
 units = Column(String(15), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a15', 'width': 15, 'format': '15.15s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a15', 'width': 15, 'format': '15.15s'})
 vang = Column(Float(24), 
-        info={'default': -1.0, 'parse': float, 'dtype': 'float', 'width': 6, 'format': '6.1f'})
+        info={'default': -1.0, 'parse': parse_float, 'dtype': 'float', 'width': 6, 'format': '6.1f'})
 vmodel = Column(String(15), 
-        info={'default': '-', 'parse': strip, 'dtype': 'a15', 'width': 15, 'format': '15.15s'})
+        info={'default': '-', 'parse': parse_str, 'dtype': 'a15', 'width': 15, 'format': '15.15s'})
 wfid = Column(Integer, 
-        info={'default': -1, 'parse': int, 'dtype': 'int', 'width': 9, 'format': '9d'})
+        info={'default': -1, 'parse': parse_int, 'dtype': 'int', 'width': 9, 'format': '9d'})
 wgt = Column(Float(24), 
-        info={'default': -1.0, 'parse': int, 'dtype': 'float', 'width': 6, 'format': '6.3f'})
+        info={'default': -1.0, 'parse': parse_float, 'dtype': 'float', 'width': 6, 'format': '6.3f'})
 
 
 class Affiliation(Base):
@@ -677,7 +683,6 @@ class Remark(Base):
     commid = commid.copy()
     lineno = lineno.copy()
     remark = remark.copy()
-    auth = auth.copy()
     lddate = lddate.copy()
 
 
